pub struct ReflectMessageFns {
pub write_message: fn(&mut World, &dyn PartialReflect, &TypeRegistry),
}Expand description
The raw function pointers needed to make up a ReflectMessage.
This is used when creating custom implementations of ReflectMessage with
ReflectMessage::new().
Note: Creating custom implementations of
ReflectMessageis an advanced feature that most users will not need. Usually aReflectMessageis created for a type by derivingReflectand adding the#[reflect(Message)]attribute. After adding the event to theTypeRegistry, itsReflectMessagecan then be retrieved when needed.
Creating a custom ReflectMessage may be useful if you need to create new
message types at runtime, for example, for scripting implementations.
By creating a custom ReflectMessage and inserting it into a type’s
TypeRegistration, you can modify the way
that reflected messages of that type will be written to the Bevy world.
Fields
write_message: fn(&mut World, &dyn PartialReflect, &TypeRegistry)Function pointer implementing ReflectMessage::write_message.
Implementations
Sourceimpl ReflectMessageFns
impl ReflectMessageFns
Sourcepub fn new<M: Message + FromReflect + TypePath>() -> Self
pub fn new<M: Message + FromReflect + TypePath>() -> Self
Get the default set of ReflectMessageFns for a specific event type
using its FromType implementation.
This is useful if you want to start with the default implementation before overriding some of the functions to create a custom implementation.