pub struct ReflectResource;Expand description
A struct that marks a reflected Resource of a type.
This is struct does not provide any functionality.
It implies the existence of a reflected Component of the same type,
which is meant to be used instead.
ⓘ
#[derive(Resource, Reflect)]
#[reflect(Resource)]
struct ResA;
// is the same as:
#[derive(Resource, Component, Reflect)]
#[reflect(Resource, Component)]
struct ResA;A ReflectResource for type T can be obtained via
bevy_reflect::TypeRegistration::data.